$GEN
$SAVE
$NOLIST
;*****************************************************************************
; File -- common.inc
; Purpose -- Include file for COS DCE boot code.  Contains equates and MACRO
;            definitions.
;
;            ------------------------   --------------------------------------
; Authors -- Original code by ...       Adapted for Boot-mode by ...
;            ------------------------   --------------------------------------
;            Mr. Daniel B. Blackman     William I. Clement, Ph.D., President
;            P.O. Box 20627             Clement Engineering, Inc.
;            Oakland, CA  94620         1261 Dogwood Road
;            (510) 910-9047             Arnold, MD  21012-2220
;                                       (410) 518-6591
;            ------------------------   --------------------------------------
;
; Change History --
; 24Aug00   Code version v17088 accepted by WIC from DBB
; 15Sep00   WIC, version 01.00 delivered.
;*****************************************************************************

; Include items mentioned by Geoff Gaines in his 001004 e-mail ...
$SET (GEOFF_CODE_001004=1)

;*****************************************************************************
;              Segment addresses for the assemble/link process
;*****************************************************************************
PATCHCST_SEG   equ   1060h    ; location of patchable constants in CODE space
                              ; for copy to XDATA space upon entry into boot
                              ; mode.  See subroutine 'COPY_PATCHABLE'.
TESTCODE_SEG   equ   9000h    ; Some test code is placed well outside the
                              ; boot code range (so it will not be in the
                              ; PROM).  This entire segment is only included
                              ; in a build if the line
                              ;   $SET (INCLUDE_TEST_CODE=1)
                              ; is included at the top of file bootmain.a51
;-----------------------------------------------------------------------------

;*****************************************************************************
;                         Boot Mode Diagnostic Codes
;*****************************************************************************
DIAG0001     equ     5A01H    ; Bad upload length
DIAG0002     equ     5A02H    ; Bad upload CRC
DIAG0003     equ     5A03H    ; Bad download length
DIAG0004     equ     5A04H    ; Wrong command MSB, should be 1
DIAG0005     equ     5A05H    ; Command byte must have twin
DIAG0006     equ     5A06H    ; Command Parameters must have complements
DIAG0011     equ     5A11H    ; Illegal command
DIAG0013     equ     5A13H    ; Command did not complete execution
DIAG0017     equ     5A17H    ; Stack Alarm (stack growing)
DIAG0018     equ     5A18H    ; Lower Code RAM CRC changed
DIAG0019     equ     5A19H    ; Upper Code RAM CRC changed
DIAG001A     equ     5A1AH    ; ROM CRC changed
DIAG001B     equ     5A1BH    ; Power-On Reset
DIAG001C     equ     5A1CH    ; Watchdog Reset
DIAG001F     equ     5A1FH    ; Commanded reset failure
DIAG002F     equ     5A2FH    ; Attempt to execute operate code while in boot
DIAG0031     equ     5A31H    ; Attempt to execute nonexistent ISR
;-----------------------------------------------------------------------------

;*****************************************************************************
;              Memory Mapped Registers (with read/write usage)
;*****************************************************************************
MUX          equ     4000h    ;   W, MUX select input to ADC
HV_STATUS    equ     4000h    ; R  , Door status (end switches and latch)
CONTROLS1    equ     4200h    ; R/W, Board C
CONTROLS2    equ     4300h    ; R/W, Board C, UNLOCK required
VMAXA        equ     4400H    ;   W, HV DAC A Max (pin 2)
VSETA        equ     4401H    ;   W, HV DAC A Setting (pin 1)
VMAXB        equ     4402H    ;   W, HV DAC B Max (pin 24)
VSETB        equ     4403H    ;   W, HV DAC B Setting (pin 23)
BILEVEL      equ     4500h    ; R  , Bilevel Status Register
ADC_SPACE    equ     4700h    ; R/W, ADC (write to start, read value)
RXD_HARDWARE equ     5000h    ; R  , read from CS computer
TXD_HARDWARE equ     5000h    ;   W, write to CS computer
COUNTERS_A   equ     6000h    ; R  , Digitizer A counters
FEC_A        equ     6000h    ; R  , Digitizer A FEC (24 bits)
DEC_A        equ     6004h    ; R  , Digitizer A DEC (24 bits)
TLC_A        equ     6008h    ; R  , Digitizer A TLC (24 bits)
COUNTERS_B   equ     6100h    ; R  , Digitizer B counters
FEC_B        equ     6100h    ; R  , Digitizer B FEC (24 bits)
DEC_B        equ     6104h    ; R  , Digitizer B DEC (24 bits)
TLC_B        equ     6108h    ; R  , Digitizer B TLC (24 bits)
PH_A         equ     6200h    ; R  , Pulse Height Histogram Side A
PH_B         equ     6300h    ; R  , Pulse Height Histogram Side B
;-----------------------------------------------------------------------------

;*****************************************************************************
;                        Housekeeping Script Opcodes
;*****************************************************************************
op_end       equ     00h      ; end of housekeeping script
op_code      equ     01h      ; copy from CODE space into housekeeping packet
op_xdata     equ     02h      ; copy from XDATA space (external RAM)
op_data      equ     03h      ; copy from DATA space (internal RAM)
op_a2d       equ     06h      ; read ADC analog (8-bit)
op_jump      equ     07h      ; jump to specified address in HKP packet
op_skip      equ     08h      ; skip 'N' bytes ahead in housekeeping packet
op_clear     equ     09h      ; clear 'N' bytes of housekeeping packet
op_nop       equ     0Ah      ; NOP -- place holder for future script command
op_TDC_A     equ     46h      ; read analog from TDC 'A'
op_TDC_B     equ     82h      ; read analog from TDC 'B'
;-----------------------------------------------------------------------------

;*****************************************************************************
;                       Command and Upload Data Buffers
;*****************************************************************************
RS00         equ     2000h       ; Boot mode base receive address
RS01         equ     RS00+0040h  ; Upload data (1024 bytes)
RS17         equ     RS00+0440h  ; Command Packet (28 bytes)
SERIALN      equ     RS17+4      ; Command Serial Number
PARAM1       equ     RS17+8      ; Command Parameter 1
PARAM2       equ     RS17+12     ; Command Parameter 2
PARAM3       equ     RS17+16     ; Command Parameter 3
PARAM4       equ     RS17+20     ; Command Parameter 4
PARAM5       equ     RS17+24     ; Command Parameter 5
;-----------------------------------------------------------------------------

;*****************************************************************************
;                   Housekeeping and Download Data Buffers
;*****************************************************************************
TS00         equ     3000h       ; Boot mode base transmit address
TS01         equ     TS00+0040h  ; Download data (1024 bytes)
TS17         equ     TS00+0440h  ; Housekeeping packet (1024 bytes)
;-----------------------------------------------------------------------------

;*****************************************************************************
;                        Patchable Constants Locations
;*****************************************************************************
PC00         equ     2460h      ; XDATA base address for working variables
PC04         equ     PC00+0100h ; XDATA address for patchable constants
;-----------------------------------------------------------------------------

;*****************************************************************************
;                       8051 Output Pins and Mnemonics
;*****************************************************************************
; TDC 3-wire interface ...
TDC_CLOCK    equ     P1.0   ; data clocked out low-to-high transition
                            ; (keep high for 1.5 us, used for both TDCs)
TDC_DATA     equ     P1.1   ; the data bit (used for both TDCs)
TDC_A_ENABLE equ     P1.2   ; 1 = TDC 'A' enabled
TDC_B_ENABLE equ     P1.3   ; 1 = TDC 'B' enabled
; Hardware Lock/Unlock interface ...
C2_LOCK      equ     P1.4   ; 1 = CONTROLS2 is locked
PHA_DIS      equ     P1.5   ; 1 = ACTEL disabled so 8051 may read PH data
                            ; 0 = ACTEL collecting and storing PH data
RAM_BANK     equ     P1.6   ; 1 = DCE-B RAM chip U8 address 0000-3FFFh
                            ; 0 = DCE-B RAM chip U8 address 4000-7FFFh
; Various reset lines ...
ACTEL_RESET  equ     P1.7   ; 0 = Reset Counter Actel (10us minimum low pulse)
                            ; 1 = Counter Actels running
HARDRESET    equ     P3.5   ; RESET control line for 8051 plus ACTEL 'CPU'
;-----------------------------------------------------------------------------

;*****************************************************************************
;                    8051 Programmable Counter Array (PCA)
;*****************************************************************************
CL           equ     0E9h   ; PCA Counter LSB
CH           equ     0F9h   ; PCA Counter MSB
CCON         equ     0D8h   ; PCA timer enable
CMOD         equ     0D9h   ; PCA clock source
CCAPM4       equ     0DEh   ; CCAPM4 setup as WatchDog Timer
CR           equ     0DEh   ; Bit in CCON
CCAP4L       equ     0EEh   ; watchdog comparitor to PCA Counter LSB
CCAP4H       equ     0FEh   ; watchdog comparitor to PCA Counter MSB
;-----------------------------------------------------------------------------

;*****************************************************************************
;                                   Macros
;*****************************************************************************
; "FILL_TO_BOUNDARY" pads code space up to the next "BOUND"-byte boundary
; with argument X.  "BOUND" must be a power of 2.
FILL_TO_BOUNDARY MACRO   BOUND, X
$SAVE
$NOLIST
check       equ  (BOUND AND (BOUND-1))
if check <> 0
   $RESTORE
   EXITM        ; BOUND wasn't a power of 2
endif
mylocation  equ  $
sizetofill  equ  (((mylocation+BOUND-1) AND (10000h-BOUND)) - mylocation)
if sizetofill = 0
   $RESTORE
   EXITM
endif
$RESTORE
   REPT   sizetofill
   DB     X
   ENDM
ENDM                        ; FILL_TO_BOUNDARY
;-----------------------------------------------------------------------------
; "ISR_SAVE_STATE" pushes several registers on the stack for context saving.
ISR_SAVE_STATE MACRO
   push  ACC
   push  B
   push  DPH
   push  DPL
   push  PSW
ENDM                        ; ISR_SAVE_STATE
;-----------------------------------------------------------------------------
; "ISR_RESTORE_STATE" pops the registers saved by "ISR_SAVE_STATE" macro.
ISR_RESTORE_STATE MACRO
   pop   PSW
   pop   DPL
   pop   DPH
   pop   B
   pop   ACC
ENDM                        ; ISR_RESTORE_STATE
;-----------------------------------------------------------------------------
; "REPORT_DIAG" saves the state of the DPTR prior to setting up and calling
; subroutine "REPORT_DIAGNOSTIC".
REPORT_DIAG MACRO   err16
   push  DPL                ; save DPTR on 8051 stack
   push  DPH
   mov   A, #LOW(err16)     ; The diagnostic code is passed in ACC
   lcall REPORT_DIAGNOSTIC  ; Record this diagnostic event
   pop   DPH                ; restore DPTR from 8051 stack
   pop   DPL
ENDM                        ; REPORT_DIAG
;-----------------------------------------------------------------------------

;*****************************************************************************
;                  PUBLIC and EXTRN Declarations (by module)
;*****************************************************************************
; Franklin Assembler/Linker places global variable _STACK at the base of
; the internal memory used.  Assigning the Stack Pointer (SP) this value
; will maximize the internal stack space available to the program.
EXTRN IDATA  (_STACK)
;-----------------------------------------------------------------------------
$if (PATCHCST)
PUBLIC        patch_table
PUBLIC        mLFSBITS1, mLFSBITS2, mLFDPERF, mLFDLSTC
PUBLIC        mLFDMEXTR, mLFDMDATA, mLFDMONS, mLFDMADD
PUBLIC        mLFDDIAGS, mDIAG_NUM, mLFDERR, mLFDERRP
PUBLIC        mLFCPKTL, mLFDCMDR, mLFDCMDX, mLFMXFER
PUBLIC        mLFCTIME
PUBLIC        mCWNS, mWNS, mTICKS, mLFDDETID
PUBLIC        mLFSBITS0, mLFSBITS1, mLFSBITS2
PUBLIC        mLFSBITS3, mLFSBITS4, mLFSBITS5
PUBLIC        mCURR_5, mCURR_NUM
PUBLIC        HSTERR_TABLE, hkp_script
PUBLIC        mLFMCRC, mLFMLWR, mLFMUPR, mLFMROM
PUBLIC        CRC_REGIONS, sz_regions, num_regions
$else
EXTRN  CODE   (patch_table)
EXTRN  XDATA  (mLFSBITS1, mLFSBITS2, mLFDPERF, mLFDLSTC)
EXTRN  XDATA  (mLFDMEXTR, mLFDMDATA, mLFDMONS, mLFDMADD)
EXTRN  XDATA  (mLFDDIAGS, mDIAG_NUM, mLFDERR, mLFDERRP)
EXTRN  XDATA  (mLFCPKTL, mLFDCMDR, mLFDCMDX, mLFMXFER)
EXTRN  XDATA  (mLFCTIME)
EXTRN  XDATA  (mCWNS, mWNS, mTICKS, mLFDDETID)
EXTRN  XDATA  (mLFSBITS0, mLFSBITS1, mLFSBITS2)
EXTRN  XDATA  (mLFSBITS3, mLFSBITS4, mLFSBITS5)
EXTRN  XDATA  (mCURR_5, mCURR_NUM)
EXTRN  NUMBER (HSTERR_TABLE, hkp_script)
EXTRN  NUMBER (mLFMCRC, mLFMLWR, mLFMUPR, mLFMROM)
EXTRN  NUMBER (CRC_REGIONS, sz_regions, num_regions)
$endif
;-----------------------------------------------------------------------------

$RESTORE

